summaryrefslogtreecommitdiff
path: root/utils/TableGen/DAGISelMatcherGen.cpp
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2010-02-18 02:53:41 +0000
committerChris Lattner <sabre@nondot.org>2010-02-18 02:53:41 +0000
commitbd8227f5298f0ab7b96203a6d3875e5d26573376 (patch)
tree357790bfab723800f0f55b68e7fa1d4f51193ec6 /utils/TableGen/DAGISelMatcherGen.cpp
parent8ef9c7958ad7a23ad15d7ff59e1377aec10ca42a (diff)
downloadllvm-bd8227f5298f0ab7b96203a6d3875e5d26573376.tar.gz
llvm-bd8227f5298f0ab7b96203a6d3875e5d26573376.tar.bz2
llvm-bd8227f5298f0ab7b96203a6d3875e5d26573376.tar.xz
rename the child field to 'next'. This is not a parent/child
relationship, this is a linear list relationship. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@96561 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'utils/TableGen/DAGISelMatcherGen.cpp')
-rw-r--r--utils/TableGen/DAGISelMatcherGen.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/utils/TableGen/DAGISelMatcherGen.cpp b/utils/TableGen/DAGISelMatcherGen.cpp
index abe0d2a6f8..53f248e692 100644
--- a/utils/TableGen/DAGISelMatcherGen.cpp
+++ b/utils/TableGen/DAGISelMatcherGen.cpp
@@ -38,7 +38,7 @@ namespace {
MatcherNode *Matcher;
/// CurPredicate - As we emit matcher nodes, this points to the latest check
/// which should have future checks stuck into its child position.
MatcherNode *CurPredicate;
public:
MatcherGen(const PatternToMatch &pattern, const CodeGenDAGPatterns &cgp);
@@ -109,7 +109,7 @@ void MatcherGen::InferPossibleTypes() {
/// AddMatcherNode - Add a matcher node to the current graph we're building.
void MatcherGen::AddMatcherNode(MatcherNode *NewNode) {
if (CurPredicate != 0)
- CurPredicate->setChild(NewNode);
+ CurPredicate->setNext(NewNode);
else
Matcher = NewNode;
CurPredicate = NewNode;
@@ -389,7 +389,7 @@ MatcherNode *llvm::ConvertPatternToMatcher(const PatternToMatch &Pattern,
// Link it into the pattern.
if (MatcherNode *Pred = Gen.GetCurPredicate()) {
- Pred->setChild(Result);
+ Pred->setNext(Result);
return Gen.GetMatcher();
}
@@ -38,7 +38,7 @@ namespace {
MatcherNode *Matcher;
/// CurPredicate - As we emit matcher nodes, this points to the latest check
- /// which should have future checks stuck into its child position.
+ /// which should have future checks stuck into its Next position.
MatcherNode *CurPredicate;
public: